@@ -25,7 +25,7 @@ BEGIN {
 	use DynaLoader ();
 	
 	use vars qw($VERSION @ISA @EXPORT);
-	$VERSION = '1.02';
+	$VERSION = '1.03';
 	@ISA = qw(Exporter DynaLoader);
 	@EXPORT = qw(
 		CloseResFile
@@ -85,6 +85,9 @@ BEGIN {
 		mapChanged
 		kResFileNotOpened
 		kSystemResFile
+
+		FSCreateResourceFile
+		FSOpenResourceFile
 	);
 }
 
